IUSE="static nls bootstrap java build"

inherit eutils flag-o-matic gcc
inherit gnuconfig

filter-flags "-fno-exceptions -fomit-frame-pointer -ggdb"

strip-flags

gcc2-flags

# Theoretical cross compiler support
[ ! -n "${CCHOST}" ] && export CCHOST="${CHOST}"


LOC="/usr"
MY_PV="`echo ${PV} | awk -F. '{ gsub(/_pre.*|_alpha.*/, ""); print $1 "." $2 }'`"
MY_PV_FULL="`echo ${PV} | awk '{ gsub(/_pre.*|_alpha.*/, ""); print $0 }'`"

LIBPATH="${LOC}/lib/gcc-lib/${CCHOST}/${MY_PV_FULL}"
BINPATH="${LOC}/${CCHOST}/gcc-bin/${MY_PV}"
DATAPATH="${LOC}/share/gcc-data/${CCHOST}/${MY_PV}"
# Dont install in /usr/include/g++/, but in gcc internal directory.
# We will handle /usr/include/g++/ with gcc-config ...
STDCXX_INCDIR="${LIBPATH}/include/g++"

S="${WORKDIR}/${P}"
DESCRIPTION="Modern C/C++ compiler written by the GNU people"
SRC_URI="ftp://gcc.gnu.org/pub/gcc/releases/${P}/${P}.tar.gz"
HOMEPAGE="http://www.gnu.org/software/gcc/gcc.html"

LICENSE="GPL-2 LGPL-2.1"
KEYWORDS="~x86 mips ~ppc ~sparc ~alpha ~arm"

# Ok, this is a hairy one again, but lets assume that we
# are not cross compiling, than we want SLOT to only contain
# $PV, as people upgrading to new gcc layout will not have
# their old gcc unmerged ...
if [ "${CHOST}" == "${CCHOST}" ]
then
	SLOT="${MY_PV}"
else
	SLOT="${CCHOST}-${MY_PV}"
fi

DEPEND="virtual/glibc
	>=sys-devel/gcc-config-1.2
	!build? ( >=sys-libs/ncurses-5.2-r2
	          nls? ( sys-devel/gettext ) )"
			  
RDEPEND="virtual/glibc
	>=sys-devel/gcc-config-1.2.3
	>=sys-libs/zlib-1.1.4
	>=sys-apps/texinfo-4.2-r4
	!build? ( >=sys-libs/ncurses-5.2-r2 )"


# Hack used to patch Makefiles to install into the build dir
FAKE_ROOT=""

src_unpack() {
    if !(use ps2)
    then
      echo "Not a ps2, wont compile"
      die
    fi
	unpack ${P}.tar.gz

	cd ${S}
	epatch ${FILESDIR}/gcc-2.95.2-frankengcc-patches.patch
	epatch ${FILESDIR}/gcc-2.95.2-single-float-const.patch
	epatch ${FILESDIR}/gcc-ps2linux-1.0.0.patch

	# Fixup libtool to correctly generate .la files with portage
#	libtoolize --copy --force &> /dev/null

	cd ${S}
	for x in $(find . -name Makefile.in)
	do
		# Fix --datadir=
		cp ${x} ${x}.orig
		sed -e 's:datadir = @datadir@:datadir = $(FAKE_ROOT)@datadir@:' \
			${x}.orig > ${x}
		
		# Fix --bindir=
		cp ${x} ${x}.orig
		sed -e 's:bindir = @bindir@:bindir = $(FAKE_ROOT)@bindir@:' \
			${x}.orig > ${x}
		
		# Fix --with-gxx-include-dir=
		cp ${x} ${x}.orig
		sed -e 's:gxx_include_dir=${includedir}:gxx_include_dir=$(FAKE_ROOT)${includedir}:' \
			${x}.orig > ${x}
		
		rm -f ${x}.orig
	done
}

src_compile() {
    local myconf=""
    if [ -z "`use build`" ]
    then
        myconf="${myconf} --enable-shared"
    else
        myconf="${myconf} --enable-languages=c"
    fi
    if [ -z "`use nls`" ] || [ "`use build`" ]
    then
        myconf="${myconf} --disable-nls"
    else
        myconf="${myconf} --enable-nls --without-included-gettext"
    fi

	# In general gcc does not like optimization, and add -O2 where
	# it is safe.
	export CFLAGS="${CFLAGS//-O?}"
	export CXXFLAGS="${CXXFLAGS//-O?}"

	gnuconfig_update

	# Build in a separate build tree
	mkdir -p ${WORKDIR}/build
	cd ${WORKDIR}/build
	cp ${FILESDIR}/config* ${S}
	einfo "Configuring GCC..."
    ${S}/configure --prefix=${LOC} \
                   --target=mipsEEel-linux \
                   --host=mipsEEel-linux \
                   --build=mipsEEel-linux \
                   --bindir=${BINPATH} \
                   --datadir=${DATAPATH} \
                   --mandir=${DATAPATH}/man \
                   --infodir=${DATAPATH}/info \
                   ${myconf} || die

    if [ -z "`use build`" ]
    then
        make  MAKEINFO="makeinfo --no-split"  bootstrap
    else
        make  MAKEINFO="makeinfo --no-split"  bootstrap-lean
    fi
}

src_install() {
	# Do allow symlinks in ${LOC}/lib/gcc-lib/${CHOST}/${PV}/include as
	# this can break the build.
	for x in cd ${WORKDIR}/build/gcc/include/*
	do
		if [ -L ${x} ]
		then
			rm -f ${x}
		fi
	done

	einfo "Installing GCC..."






	cd ${WORKDIR}/build

	S="${WORKDIR}/build" \
	make prefix=${D}${LOC} \
		bindir=${D}${BINPATH} \
		datadir=${D}${DATAPATH} \
		mandir=${D}${DATAPATH}/man \
		infodir=${D}${DATAPATH}/info \
		LIBPATH="${LIBPATH}" \
		FAKE_ROOT="${D}" \
		MAKEINFO="makeinfo --no-split" \
		install || die
	
	[ -r ${D}${BINPATH}/gcc ] || die "gcc not found in ${D}"
	
	dodir /lib /usr/bin
	dodir /etc/env.d/gcc

echo "PATH=\"/usr/mips-unknown-linux-gnu/gcc-bin/2.95\"" > ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "ROOTPATH=\"/usr/mips-unknown-linux-gnu/gcc-bin/2.95\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "LDPATH=\"/usr/lib/gcc-lib/mipsEEel-linux/2.95.2\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "MANPATH=\"/usr/share/gcc-data/mips-unknown-linux-gnu/2.95/man\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "INFOPATH=\"/usr/share/gcc-data/mips-unknown-linux-gnu/2.95/info\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "STDCXX_INCDIR=\"g++\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "CC=\"gcc\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2
echo "CXX=\"g++\"" >> ${D}/etc/env.d/gcc/mipsEEel-linux-2.95.2


file ${D}/usr/bin/* | grep ELF | cut -d':' -f1 | xargs strip || :
# fix some things
ln -f ${D}/usr/bin/mipsEEel-linux-gcc ${D}/usr/bin/gcc
ln -sf gcc ${D}/usr/bin/cc
ln -fs ../mips-unknown-linux-gnu/gcc-bin/2.95/gcc ${D}/usr/bin/gcc
ln -fs ../mips-unknown-linux-gnu/gcc-bin/2.95/g++ ${D}/usr/bin/g++
ln -fs ../mips-unknown-linux-gnu/gcc-bin/2.95/c++ ${D}/usr/bin/c++
ln -fs ../mips-unknown-linux-gnu/gcc-bin/2.95/g77 ${D}/usr/bin/g77
# mv ${D}/usr/include/g++-3 ${D}/usr/include/g++


    if [ -z "`use build`" ]
    then
        rm -f ${D}/usr/info/dir
        gzip -n -9f ${D}/usr/info/*.info* 
        ln -sf g77.1 ${D}/usr/man/man1/f77.1
        ln -sf g77 ${D}/usr/bin/f77
        mkdir -p ${D}/lib
        ln -sf ../usr/bin/cpp ${D}/lib/cpp
        ln -sf cccp.1 ${D}/usr/man/man1/cpp.1
    else
        rm -rf ${D}/usr/share/{man,info}
    fi



	
}

pkg_postinst() {
	gcc-config mipsEEel-linux-2.95.2
}

