IUSE="nls pic build"

inherit flag-o-matic gcc

filter-flags "-fomit-frame-pointer -malign-double"

# Sparc support
replace-flags "-mcpu=ultrasparc" "-mcpu=v8 -mtune=ultrasparc"
replace-flags "-mcpu=v9" "-mcpu=v8 -mtune=v9"

strip-flags

S="${WORKDIR}/${P}"
DESCRIPTION="GNU libc6 (also called glibc2) C library"
SRC_URI="http://ftp.gnu.org/gnu/glibc/glibc-${PV}.tar.gz
	 http://ftp.gnu.org/gnu/glibc/glibc-linuxthreads-${PV}.tar.gz"
HOMEPAGE="http://www.gnu.org/software/libc/libc.html"

KEYWORDS="~x86 ~ppc ~sparc ~alpha ~arm mips"
SLOT="2.2"
LICENSE="LGPL-2"

# Portage-1.8.9 needed for smart library merging feature (avoids segfaults on glibc upgrade)
# drobbins, 18 Mar 2002: we now rely on the system profile to select the correct linus-headers
DEPEND="virtual/os-headers
	nls? ( sys-devel/gettext )"
RDEPEND="virtual/os-headers
	sys-apps/baselayout
	nls? ( sys-devel/gettext )
	build? ( >=sys-apps/portage-1.9.0 )"

PROVIDE="virtual/glibc"

# Lock glibc at -O2 -- linuxthreads needs it and we want to be conservative here
export CFLAGS="${CFLAGS//-O?} -O2"
export CFLAGS="${CFLAGS/-mips2/}"
export CFLAGS="${CFLAGS/-mcpu=5900/}"
export CXXFLAGS="${CFLAGS}"

src_unpack() {
    if !(use ps2)
    then
      echo "Not a ps2, wont compile"
      die
    fi

	unpack glibc-${PV}.tar.gz || die
	cd ${S}


	cd ${S}
	unpack glibc-linuxthreads-${PV}.tar.gz || die

	einfo "Applying glibc-2linux patch"
	patch -p1 < ${FILESDIR}/glibc-ps2linux-1.0.0.patch  || die
	einfo "Applying linuxthreads-2.2.2-mysql.patch "
	patch -p0 < ${FILESDIR}/linuxthreads-2.2.2-mysql.patch  || die
	einfo "Weird ass doc patch "
	patch -p0 < ${FILESDIR}/stdio.texi.patch  || die

}

src_compile() {
	rsync -avx /root/glibc-2.2.2 /var/tmp/portage
	einfo "Building GLIBC..."
	make -r || die
}


src_install() {
    export LC_ALL="C"
    einfo "Installing GLIBC..."
    make install_root=${D} install || die

    if [ -z "`use build`" ]
    then
        einfo "Installing Info pages..."
        make install_root=${D} info

        einfo "Installing Locale data..."
        make install_root=${D} install-locales -C localedata

        einfo "Installing man pages and docs..."
        # Install linuxthreads man pages
        dodir /usr/share/man/man3
        make -C linuxthreads/man
        install -m 0644 linuxthreads/man/*.3thr ${D}/usr/man/man3
        gzip -9nvf ${D}/usr/info/libc*

        # Install nscd config file
        insinto /etc
        doins ${S}/nscd/nscd.conf

        dodoc BUGS ChangeLog* CONFORMANCE COPYING* FAQ INTERFACE \
            NEWS NOTES PROJECTS README*
    else
        rm -rf ${D}/usr/share ${D}/usr/lib/gconv
    fi







   rm -rf ${D}/usr/share/zoneinfo/{localtime,posixtime,posixrules}
  # this one conflicts badly with the kernel
   rm -rf ${D}/usr/include/scsi

  ln -sf ../../../etc/localtime ${D}/usr/share/zoneinfo/localtime
  ln -sf localtime ${D}/usr/share/zoneinfo/posixtime
  ln -sf localtime ${D}/usr/share/zoneinfo/posixrules
  ln -sf ../../usr/lib/libbsd-compat.a ${D}/usr/lib/libbsd.a

		
	fperms 4755 /usr/lib/misc/pt_chown
	
	rm -f ${D}/etc/ld.so.cache

	rm -f ${D}/etc/localtime


}

pkg_postinst() {
	# Correct me if I am wrong here, but my /etc/localtime is a file
	# created by zic ....
	# I am thinking that it should only be recreated if no /etc/localtime
	# exists, or if it is an invalid symlink.
	#
	# For invalid symlink:
	#   -f && -e  will fail
	#   -L will succeed
	#
	if [ ! -e ${ROOT}/etc/localtime ]
	then
		echo "Please remember to set your timezone using the zic command."
		rm -f ${ROOT}/etc/localtime
		ln -s ../usr/share/zoneinfo/Factory ${ROOT}/etc/localtime
	fi
}

